summaryrefslogtreecommitdiff
path: root/tests/regression-funcs.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tests/regression-funcs.sh')
-rwxr-xr-xtests/regression-funcs.sh32
1 files changed, 25 insertions, 7 deletions
diff --git a/tests/regression-funcs.sh b/tests/regression-funcs.sh
index 3728d44980..0c7d34bea3 100755
--- a/tests/regression-funcs.sh
+++ b/tests/regression-funcs.sh
@@ -1,6 +1,6 @@
#!/bin/sh
#
# common regression functions for avconv
#
#
@@ -11,6 +11,7 @@ target_exec=$4
target_path=$5
threads=${6:-1}
cpuflags=${8:-all}
+target_samples=$9
datadir="./tests/data"
target_datadir="${target_path}/${datadir}"
@@ -18,11 +19,13 @@ target_datadir="${target_path}/${datadir}"
this="$test.$test_ref"
outfile="$datadir/$test_ref/"
-# various files
-avconv="$target_exec ${target_path}/avconv"
+ # various files
+ffmpeg="$target_exec ${target_path}/ffmpeg${PROGSUF}"
raw_src="${target_path}/$raw_src_dir/%02d.pgm"
raw_dst="$datadir/$this.out.yuv"
pcm_src="$target_datadir/asynth1.sw"
+pcm_src_1ch="$target_datadir/asynth-16000-1.wav"
+pcm_ref_1ch="$datadir/$test_ref-16000-1.ref.wav"
crcfile="$datadir/$this.crc"
target_crcfile="$target_datadir/$this.crc"
@@ -40,15 +43,15 @@ echov(){
. $(dirname $0)/md5.sh
-AVCONV_OPTS="-nostats -y -cpuflags $cpuflags"
+AVCONV_OPTS="-nostdin -nostats -y -cpuflags $cpuflags"
COMMON_OPTS="-flags +bitexact -idct simple -sws_flags +accurate_rnd+bitexact -fflags +bitexact"
DEC_OPTS="$COMMON_OPTS -threads $threads"
-ENC_OPTS="$COMMON_OPTS -threads 1 -dct fastint"
+ENC_OPTS="$COMMON_OPTS -threads $threads -dct fastint"
run_avconv()
{
- $echov $avconv $AVCONV_OPTS $*
- $avconv $AVCONV_OPTS $*
+ $echov $ffmpeg $AVCONV_OPTS $*
+ $ffmpeg $AVCONV_OPTS $*
}
do_avconv()
@@ -61,6 +64,21 @@ do_avconv()
echo $(wc -c $f)
}
+do_avconv_nomd5()
+{
+ f="$1"
+ shift
+ set -- $* ${target_path}/$f
+ run_avconv $*
+ if [ $f = $raw_dst ] ; then
+ $tiny_psnr $f $raw_ref
+ elif [ $f = $pcm_dst ] ; then
+ $tiny_psnr $f $pcm_ref 2
+ else
+ echo $(wc -c $f)
+ fi
+}
+
do_avconv_crc()
{
f="$1"
@@ -1,6 +1,6 @@
#!/bin/sh
#
-# common regression functions for avconv
+# common regression functions for ffmpeg
#
#